{% extends 'base.html' %}

{% block content %}
<div class="row">
  <div class="col-md-6">
    <div class="card">
      <div class="card-header">
        <h3 class="card-title">Request Data</h3>
      </div>
      <div class="card-body">
        <div class="form-group">
          <label>Api Endpoint</label>
          <pre class="heighlight">{{ request.host_url }}api/{{ params.pid }}</pre>
        </div>
        <div class="form-group">
          <label>Api Method</label>
          <pre class="heighlight">POST</pre>
        </div>
        <div class="form-group">
          <label>POST Data</label>
          <pre class="heighlight">{{ input_data }}</pre>
        </div>
      </div>
    </div>
  </div>
  <div class="col-md-6">
    <div class="card">
      <div class="card-header">
        <h3 class="card-title">Api Output</h3>
      </div>
      <div class="card-body">
        <pre class="heighlight">{{ output_data }}</pre>
      </div>
    </div>
  </div>
</div>
{% endblock %}