{% extends 'base.html' %}

{% block content %}
<div class="card">
  <div class="card-header">
    <h3 class="card-title">Task Runtime Log</h3>
  </div>
  <div class="card-body">
    <div class="form-group">
      <pre class="heighlight">{{ data }}</pre>
    </div>
  </div>
</div>
{% endblock %}